#!/usr/bin/perl
 
package inc::MyBuilder;
 
 
use strict;
use warnings;
 
use base 'Module::Build';
use File::Spec::Functions;

our $gtk2_version;

# Take the gtk2_version parameter from our declaration before passing it
# up to the Module:Build Super Class
sub new {
	my ($class, @args) = @_;
	# Read through the parameter names (every second item in array)	
	for(my $i = 0; $i < @args; $i=$i+2) {
		my $key = $args[$i];
		# Remove gtk2_version
		if($key eq 'gtk2_version') {
			$gtk2_version = $args[$i+1];
			splice(@args, $i, 2);
			last;
		}
	}	
	# Pass them on up
	my $new = $class->SUPER::new(@args);
	return $new;
} 

# Check normal prerequisites and check on System's Gtk2 version
sub check_prereq {
	my $self = shift;
	my ($major, $minor, $micro, $passed);
	# Check the  normal prerequisites are met 
	my $prereq_ok = $self->SUPER::check_prereq(@_);
	# Check that Perl has Gtk2 module
	eval 'use Gtk2';
	my $gtk_ok = !$@;
	# Report on perl module error or check System's Gtk2 version
	# to make sure that it's new enough to support Gtk2::Builder
	if(!$gtk_ok) {
		$self->log_warn(" * ERROR: Could not load perl module Gtk2\n");
	} elsif($gtk2_version) { 
		($major, $minor, $micro) = split('\.', $gtk2_version);
		if($major=~/^\d+$/ && $minor=~/^\d+$/ && $micro=~/^\d+$/) {
			$passed = Gtk2->CHECK_VERSION($major, $minor, $micro);
		} else {
			$self->log_warn(" * Warning: Bad check against Gtk2 version: $gtk2_version\n");
		}
		if(!$passed) {
			$gtk_ok = 0;
			my $version=join('.', Gtk2->GET_VERSION_INFO);
			$self->log_warn(
				" * ERROR: gtk+ version $version is installed, but we need >= $gtk2_version\n" .
				"   If you think you have the right version of gtk+ installed, try\n" .
				"   recompiling the Gtk2 perl package.\n");
		}
	}
	# Report on prerequisite errors
	if(!$prereq_ok) {
		$self->log_warn(
			"ERRORS/WARNINGS FOUND IN PREREQUISITES.  You may wish to install the versions\n" .
			"of the modules indicated above before proceeding with this installation\n");
	}
	# Return if prerequisites were met
	return $prereq_ok && $gtk_ok;
} 
 
sub ACTION_install {
	my $self = shift;
 
	# Make sure that 'share/' has an installation path
	my $p = $self->{properties};
	if (! exists $p->{install_path}{share}) {
		my $script_dir = $self->install_destination('script');
		my @dirs = File::Spec->splitdir($script_dir);
		$dirs[-1] = 'share';
		$p->{install_path}{share} = File::Spec->catdir(@dirs);
	}
 
	# Proceed normally
	$self->SUPER::ACTION_install(@_);
}
 
 
sub ACTION_post_install {
	my $self = shift;
	print "Updating desktop database\n";
	system('update-desktop-database');
}
 
 
sub ACTION_build {
	my $self = shift;
 
	# Copy the files in share/
	foreach my $entry (@{ $self->rscan_dir('share') }) {
 
		# Skip hidden entries or folders
		next if $entry =~ m,(^|/)\., or -d $entry;
 
		$self->copy_if_modified(
			from => $entry,
			to => catfile($self->blib, $entry)
			);
	}
 
	# Proceed normally
	$self->SUPER::ACTION_build(@_);
}
 
 
# Return a true value
1;
